==> psxc-imdb_v1.3.tgz: psxc-imdb/psxc-imdb-full.tcl <==
################################
# PSXC-IMDB bot-addon-full v1.3
# -----------------------------
# Tcl is really not my strong suit, so do not be surprised if your computer
# blows up when you run this script.
#
# This little thingy can be used instead of adding stuff to crontab. It does
# basically the same thing, only this will react instantly on .nfo uploads.
# It will also be used instead of your normal bot config to output stuff in
# (one) channel.
#
# edit the (not so) advanced config below, then copy this script to your bot's
# script directory and add the following to your eggdrop.conf:
#
#   source scripts/psxc-imdb-full.tcl
#

###################
##### config ######

# location of psxc-imdb.log file (aka IMDBLOG)
set psxc(IMDBLOG)     "/glftpd/ftp-data/logs/psxc-imdb.log"

# location of imdb-script.sh
set psxc(IMDBSCRIPT)  "/glftpd/bin/psxc-imdb.sh"

# location of psxc-moviedata.log file (aka GLLOG)
# !! DO NOT USE glftpd.log HERE !!
set psxc(IMDBMOVIE)   "/glftpd/ftp-data/logs/psxc-moviedata.log"

# announce-channel(s) - separate by space
set psxc(IMDBCHANNEL) "#pleasechange"

# should the lines start with something?
set psxc(IMDBTRIG) "\002IMDb:\002"
#
##### config done #####
#######################

proc readimdb {} {
 global psxc psxclog psxcmovie
 utimer 5 "readimdb"
 set psxclogsize [file size $psxc(IMDBLOG)]
 if { $psxclogsize == $psxclog } { return 0 }
 if { $psxclogsize  < $psxclog } { set psxclog 0 }
 set psxcbscript $psxc(IMDBSCRIPT)
 set psxcbout [ exec $psxcbscript]
 set psxclog [file size $psxc(IMDBLOG)]
 set psxcmoviesize [file size $psxc(IMDBMOVIE)]
 if { $psxcmoviesize == $psxcmovie } { return 0 }
 if { $psxcmoviesize  < $psxcmovie } { set psxcmovie 0 }
 if { [catch { set psxcoffset [open $psxc(IMDBMOVIE) r] } ] } { return 0 }
 seek $psxcoffset $psxcmovie
 while {![eof $psxcoffset]} {
  set psxcline [gets $psxcoffset]
  if {$psxcline == ""} {continue}
  set psxcthr [lindex $line 7]
  foreach psxcimdbchan $psxc(IMDBCHANNEL) { putserv "PRIVMSG $psxcimdbchan :$psxc(IMDBTRIG) $psxcthr" }
 }
 close $psxcoffset
 set psxcmovie [file size $psxc(IMDBMOVIE)]
 return 0
}
set psxclog 0
set psxcmovie [file size $psxc(IMDBMOVIE)]
readimdb
putlog "Loaded: psxc-imdb bot-addon (full) v1.3"

==> psxc-imdb_v1.31.tgz: psxc-imdb/psxc-imdb-full.tcl <==
################################
# PSXC-IMDB bot-addon-full v1.31
# -----------------------------
# Tcl is really not my strong suit, so do not be surprised if your computer
# blows up when you run this script.
#
# This little thingy can be used instead of adding stuff to crontab. It does
# basically the same thing, only this will react instantly on .nfo uploads.
# It will also be used instead of your normal bot config to output stuff in
# (one) channel.
#
# edit the (not so) advanced config below, then copy this script to your bot's
# script directory and add the following to your eggdrop.conf:
#
#   source scripts/psxc-imdb-full.tcl
#

###################
##### config ######

# location of psxc-imdb.log file (aka IMDBLOG)
set psxc(IMDBLOG)     "/glftpd/ftp-data/logs/psxc-imdb.log"

# location of imdb-script.sh
set psxc(IMDBSCRIPT)  "/glftpd/bin/psxc-imdb.sh"

# location of psxc-moviedata.log file (aka GLLOG)
# !! DO NOT USE glftpd.log HERE !!
set psxc(IMDBMOVIE)   "/glftpd/ftp-data/logs/psxc-moviedata.log"

# announce-channel(s) - separate by space
set psxc(IMDBCHANNEL) "#changethis"

# should the lines start with something?
set psxc(IMDBTRIG) "\002IMDb:\002"
#
##### config done #####
#######################

proc readimdb {} {
 global psxc psxclog
 utimer 5 "readimdb"
 set psxclogsize [file size $psxc(IMDBLOG)]
 if { $psxclogsize == $psxclog } { return 0 }
 if { $psxclogsize  < $psxclog } { set psxclog 0 }
 set psxcascript $psxc(IMDBSCRIPT)
 set psxcaout [ exec $psxcascript]
 set psxclog [file size $psxc(IMDBLOG)]
 return 0
}

proc showimdb {} {
 global psxc psxclog psxcmovie
 utimer 5 "showimdb"
 set psxcmoviesize [file size $psxc(IMDBMOVIE)]
 if { $psxcmoviesize == $psxcmovie } { return 0 }
 if { $psxcmoviesize  < $psxcmovie } { set psxcmovie 0 }
 if { [catch { set psxcoffset [open $psxc(IMDBMOVIE) r] } ] } { return 0 }
 seek $psxcoffset $psxcmovie
 while {![eof $psxcoffset]} {
  set psxcline [gets $psxcoffset]
  if {$psxcline == ""} {continue}
  set psxcthr [lindex $psxcline 7]
  foreach psxcimdbchan $psxc(IMDBCHANNEL) { putserv "PRIVMSG $psxcimdbchan :$psxc(IMDBTRIG) $psxcthr" }
 }
 close $psxcoffset
 set psxcmovie [file size $psxc(IMDBMOVIE)]
 return 0
}
set psxclog 0
set psxcmovie [file size $psxc(IMDBMOVIE)]
readimdb
showimdb
putlog "Loaded: psxc-imdb bot-addon (full) v1.31"
